@@ -266,8 +266,8 @@ OC.L10N.register(
     "Checking …" : "Gaan tans na …",
     "Confirm" : "Bevestig",
     "Reset" : "Herstel",
-    "Back" : "Terug",
     "Cancel" : "Kanselleer",
+    "Back" : "Terug",
     "From" : "Van",
     "To" : "Aan",
     "Calendar" : "Kalender",
@@ -291,6 +291,7 @@ OC.L10N.register(
     "Log in" : "Teken Aan",
     "Remove from favorites" : "Verwyder uit gunstelinge",
     "Add to favorites" : "Voeg by gunstelinge",
+    "Home" : "Tuis",
     "Users" : "Gebruikers",
     "Groups" : "Groepe",
     "You are currently waiting in the lobby" : "U wag tans in die voorportaal",
@@ -300,8 +301,6 @@ OC.L10N.register(
     "Reply" : "Antwoord",
     "Dismiss" : "Ontslaan",
     "Contact" : "Kontak",
-    "Today" : "Vandag",
-    "Yesterday" : "Gister",
     "Add participants" : "Voeg deelnemers toe",
     "Enter password" : "Voer wagwoord in",
     "Send" : "Stuur",
@@ -312,9 +311,7 @@ OC.L10N.register(
     "Chat" : "Klets",
     "Details" : "Besonderhede",
     "Privacy" : "Privaatheid",
-    "Keyboard shortcuts" : "Sneltoetse",
     "Search" : "Soek",
-    "Default" : "Verstek",
     "Keep" : "Hou",
     "Select a region" : "Kies ’n streek",
     "Submit" : "Dien in",
@@ -326,6 +323,7 @@ OC.L10N.register(
     "Media" : "Media",
     "Audio" : "Oudio",
     "Other" : "Ander",
+    "Default" : "Verstek",
     "Group" : "Groep",
     "Please reload the page." : "Herlaai asseblief die bladsy.",
     "Do not disturb" : "Moenie pla nie",
@@ -335,6 +333,8 @@ OC.L10N.register(
     "iOS app" : "iOS-toep",
     "__language_name__" : "Afrikaans",
     "Tasks" : "Take",
-    "Close" : "Sluit"
+    "Today" : "Vandag",
+    "Yesterday" : "Gister",
+    "Keyboard shortcuts" : "Sneltoetse"
 },
 "nplurals=2; plural=(n != 1);");
