@@ -610,8 +610,8 @@ OC.L10N.register(
     "OK" : "U redu",
     "Confirm" : "Potvrdi",
     "Reset" : "Resetiraj",
-    "Back" : "Natrag",
     "Cancel" : "Odustani",
+    "Back" : "Natrag",
     "Add participant \"{user}\"" : "Dodaj sudionika „{user}”",
     "Loading …" : "Učitavanje…",
     "From" : "Od",
@@ -688,18 +688,18 @@ OC.L10N.register(
     "Personal" : "Osobno",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zona opasnosti",
+    "Leave conversation" : "Napusti razgovor",
+    "Delete conversation" : "Izbriši razgovor",
     "Do you really want to delete \"{displayName}\"?" : "Želite li zaista izbrisati „{displayName}“?",
-    "Do you really want to delete all messages in \"{displayName}\"?" : "Želite li zaista izbrisati sve poruke u „{displayName}“?",
     "Error while deleting conversation" : "Pogreška pri brisanju razgovora",
+    "Delete all chat messages" : "Izbriši sve razmijenjene poruke",
+    "Do you really want to delete all messages in \"{displayName}\"?" : "Želite li zaista izbrisati sve poruke u „{displayName}“?",
     "Error while clearing chat history" : "Pogreška pri brisanju povijesti razmjene poruka",
     "Be careful, these actions cannot be undone." : "Pažljivo nastavite jer ove radnje nije moguće poništiti.",
-    "Leave conversation" : "Napusti razgovor",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Nakon izlaska iz razgovora za ponovni pristup zatvorenom razgovoru potreban je poziv. Otvorenom razgovoru možete se ponovno pridružiti u bilo kojem trenutku.",
-    "Delete conversation" : "Izbriši razgovor",
     "Permanently delete this conversation." : "Trajno izbrišite ovaj razgovor.",
     "Delete chat messages" : "Izbriši razmijenjene poruke",
     "Permanently delete all the messages in this conversation." : "Trajno izbrišite sve poruke u ovom razgovoru.",
-    "Delete all chat messages" : "Izbriši sve razmijenjene poruke",
     "Password protection" : "Zaštita zaporkom",
     "Set a password" : "Postavi zaporku",
     "Save password" : "Spremi zaporku",
@@ -753,7 +753,7 @@ OC.L10N.register(
     "Conversation list" : "Popis razgovora",
     "Unread messages" : "Nepročitane poruke",
     "Clear filter" : "Ukloni filtar",
-    "Talk settings" : "Postavke razgovora",
+    "App settings" : "Postavke aplikacije",
     "Users" : "Korisnici",
     "Groups" : "Grupe",
     "Open conversations" : "Otvori razgovore",
@@ -780,6 +780,7 @@ OC.L10N.register(
     "Upload" : "Otpremi",
     "Files" : "Datoteke",
     "Reply" : "Odgovori",
+    "More actions" : "Dodatne radnje",
     "Reply privately" : "Odgovori privatno",
     "Copy message link" : "Kopiraj poveznicu poruke",
     "Go to file" : "Idi na datoteku",
@@ -891,7 +892,6 @@ OC.L10N.register(
     "Link to a conversation" : "Poveznica za sudjelovanje u razgovoru",
     "Search conversations or users" : "Pretraži razgovore ili korisnike",
     "Select conversation" : "Odaberi razgovor",
-    "Choose the folder in which attachments should be saved." : "Odaberite mapu za spremanje privitaka.",
     "Select location for attachments" : "Odaberite lokaciju privitaka",
     "Error while setting attachment folder" : "Pogreška pri postavljanju mape za privitke",
     "Your privacy setting has been saved" : "Postavka privatnosti je spremljena",
@@ -899,25 +899,17 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Spremanje postavki zvukova nije uspjelo",
     "Sounds setting saved" : "Postavka zvukova je spremljena",
     "Error while saving sounds setting" : "Pogreška pri spremanju postavke zvukova",
-    "Attachments folder" : "Mapa s privicima",
-    "Appearance" : "Izgled",
-    "Privacy" : "Privatnost",
-    "Share my read-status and show the read-status of others" : "Dijeli moj status čitanja i prikaži statuse čitanja drugih sudionika",
-    "Sounds" : "Zvuci",
     "Play sounds when participants join or leave a call" : "Reproduciraj zvukove kad se sudionici pridruže ili napuste poziv",
-    "Performance" : "Učinkovitost",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
-    "Speed up your Talk experience with these quick shortcuts." : "Ubrzajte korištenje aplikacije Talk s pomoću ovih brzih prečaca.",
+    "Notification settings" : "Postavke obavijesti",
+    "Privacy" : "Privatnost",
+    "Attachments folder" : "Mapa s privicima",
+    "Search" : "Traži",
     "Focus the chat input" : "Fokusirajte ulazne poruke",
     "Unfocus the chat input to use shortcuts" : "Odfokusirajte ulazne poruke kako biste iskoristili prečace",
-    "Fullscreen the chat or call" : "Razmjena poruka ili poziv preko cijelog zaslona",
-    "Search" : "Traži",
     "Shortcuts while in a call" : "Prečaci tijekom poziva",
     "Microphone on and off" : "Mikrofon uključen i isključen",
-    "Space bar" : "Razmaknica",
-    "Push to talk or push to mute" : "Pritisni za govor ili pritisni za utišavanje",
     "Raise or lower hand" : "Podigni ili spusti ruku",
-    "More actions" : "Dodatne radnje",
+    "Push to talk or push to mute" : "Pritisni za govor ili pritisni za utišavanje",
     "Start call" : "Uputi poziv",
     "You will be able to join the call only after a moderator starts it." : "Pozivu ćete se moći pridružiti tek nakon što ga moderator pokrene.",
     "Recording" : "Snimanje",
@@ -1066,10 +1058,20 @@ OC.L10N.register(
     "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
     "Join »%s«" : "Pridruži se »%s«",
     "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
+    "Talk settings" : "Postavke razgovora",
     "Today" : "Danas",
     "Yesterday" : "Jučer",
     "_%n day ago_::_%n days ago_" : ["Prije %n dana","Prije %n dana","Prije %n dana"],
+    "Choose the folder in which attachments should be saved." : "Odaberite mapu za spremanje privitaka.",
     "Choose devices" : "Odaberi uređaje",
+    "Appearance" : "Izgled",
+    "Share my read-status and show the read-status of others" : "Dijeli moj status čitanja i prikaži statuse čitanja drugih sudionika",
+    "Sounds" : "Zvuci",
+    "Performance" : "Učinkovitost",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Speed up your Talk experience with these quick shortcuts." : "Ubrzajte korištenje aplikacije Talk s pomoću ovih brzih prečaca.",
+    "Fullscreen the chat or call" : "Razmjena poruka ili poziv preko cijelog zaslona",
+    "Space bar" : "Razmaknica",
     "Blur background" : "Zamuti pozadinu",
     "Sharing your screen only works with Firefox version 52 or newer." : "Dijeljenje zaslona moguće je samo u pregledniku Firefox, inačice 52 ili novije.",
     "Screensharing extension is required to share your screen." : "Za dijeljenje zaslona potrebno je instalirati proširenje za dijeljenje zaslona.",
