@@ -588,8 +588,8 @@ OC.L10N.register(
     "Web server setup checks" : "Verificacions de configuracion del servidor Web",
     "Confirm" : "Confirmar",
     "Reset" : "Reïnicializar",
-    "Back" : "Retorn",
     "Cancel" : "Anullar",
+    "Back" : "Retorn",
     "Add participant \"{user}\"" : "Apondre participant « {user} »",
     "Loading …" : "Cargament…",
     "From" : "De",
@@ -677,18 +677,18 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zòna perilhosa",
+    "Leave conversation" : "Quitar la conversacion",
+    "Delete conversation" : "Suprimir la conversacion",
     "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
-    "Do you really want to delete all messages in \"{displayName}\"?" : "Volètz vertadièrament suprimir totes los messatges dins « {displayName} » ?",
     "Error while deleting conversation" : "Error pendent la supression de la conversacion",
+    "Delete all chat messages" : "Suprimir totes los messatges del chat",
+    "Do you really want to delete all messages in \"{displayName}\"?" : "Volètz vertadièrament suprimir totes los messatges dins « {displayName} » ?",
     "Error while clearing chat history" : "Error pendent l’escafament de l’istoric del chat",
     "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
-    "Leave conversation" : "Quitar la conversacion",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Un còp quitada, per tornar a un conversacion tampada, cal un convit. Una conversacion dubèrta es totjorn accessibla.",
-    "Delete conversation" : "Suprimir la conversacion",
     "Permanently delete this conversation." : "Suprimir permanent aquesta conversacion",
     "Delete chat messages" : "Suprimir los messatges del chat",
     "Permanently delete all the messages in this conversation." : "Suprimir per totjorn totes los messatges d’aquesta conversacion.",
-    "Delete all chat messages" : "Suprimir totes los messatges del chat",
     "_%n hour_::_%n hours_" : ["%n ora","%n oras"],
     "_%n day_::_%n days_" : ["%n jorn","%n jorns"],
     "_%n week_::_%n weeks_" : ["%n setmana","%n setmanas"],
@@ -741,7 +741,7 @@ OC.L10N.register(
     "Conversation list" : "Lista de conversacion",
     "Unread messages" : "Messatges pas legits",
     "Clear filters" : "Escafar los filtres",
-    "Talk settings" : "Paramètres Talk",
+    "App settings" : "Paramètres d’aplicacion",
     "Users" : "Utilizaires",
     "Groups" : "Gropes",
     "Open conversations" : "Dobrir las conversacions",
@@ -767,9 +767,9 @@ OC.L10N.register(
     "Invalid path selected" : "Camin seleccionat invalid",
     "Upload" : "Cargament",
     "Files" : "Fichièrs",
-    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Add a reaction to this message" : "Apondre una reaccion a aqueste messatge",
     "Reply" : "Respondre",
+    "More actions" : "Mai d’accions",
     "Reply privately" : "Respondre en privat",
     "Copy message link" : "Copiar ligam messatge",
     "Go to file" : "Anar al fichièr",
@@ -914,7 +914,6 @@ OC.L10N.register(
     "Phone numbers" : "Numèros de telefòn",
     "Display name: {name}" : "Nom d’afichatge : {name}",
     "Save name" : "Enregistrar lo nom",
-    "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
     "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
     "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
     "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
@@ -922,22 +921,17 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
     "Sounds setting saved" : "Paramètres de son enregistrats",
     "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
-    "Attachments folder" : "Dossièr de pèças-juntas",
-    "Browse …" : "Percórrer...",
-    "Privacy" : "Confidencialitat",
-    "Sounds" : "Sons",
     "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
-    "Keyboard shortcuts" : "Acorchis de clavièr",
-    "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
-    "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
+    "Notification settings" : "Paramètres de notificacions",
+    "Privacy" : "Confidencialitat",
+    "Attachments folder" : "Dossièr de pèças-juntas",
+    "Toggle full screen" : "Alternar ecran complèt",
     "Search" : "Search",
     "Shortcuts while in a call" : "Acorchis pendent una sonada",
     "Camera on and off" : "Vidèo activada/desactivada",
     "Microphone on and off" : "Microfòn activat/desactivat",
-    "Space bar" : "barra d’espaci",
-    "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
     "Raise or lower hand" : "Levar o baissar la man",
-    "More actions" : "Mai d’accions",
+    "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
     "Start call silently" : "Començar la sonada en silenci",
     "Start call" : "Començar sonada",
     "End call" : "Acabar la sonada",
@@ -974,7 +968,6 @@ OC.L10N.register(
     "Stop screensharing" : "Arrestar partiment d’ecran",
     "Mute others" : "Copar lo son dels autres",
     "Start recording" : "Lançar l'enregistrament",
-    "Toggle full screen" : "Alternar ecran complèt",
     "Select a region" : "Seleccionatz una region",
     "Submit" : "Transmetre",
     "Search …" : "Recercar...",
@@ -1072,6 +1065,7 @@ OC.L10N.register(
     "Failed to add reaction" : "Apondon impossible de reaccion",
     "Failed to remove reaction" : "Supression impossibla de reaccion",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
+    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Lost connection to signaling server. Trying to reconnect." : "Connexion perduda al servidor de senhalament. Ensag de reconnexion.",
     "Establishing signaling connection is taking longer than expected …" : "L’establiment de la connexion de senhalizacion pren mai de temps que previst…",
     "Failed to establish signaling connection. Retrying …" : "Fracàs de l’establiment de la connexion de senhalizacion. Novèl ensag…",
@@ -1101,11 +1095,20 @@ OC.L10N.register(
     "Click the button below to join." : "Clicatz sul boton per participar.",
     "Join »%s«" : "Rejónher « %s »",
     "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
+    "Talk settings" : "Paramètres Talk",
     "Media settings" : "Paramètres dels mèdias",
     "Today" : "Uèi",
     "Yesterday" : "Ièr",
     "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
+    "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
     "Choose devices" : "Causir periferics",
+    "Browse …" : "Percórrer...",
+    "Appearance" : "Aparéncia",
+    "Sounds" : "Sons",
+    "Keyboard shortcuts" : "Acorchis de clavièr",
+    "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
+    "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
+    "Space bar" : "barra d’espaci",
     "Blur background" : "Rèireplan trebol",
     "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
     "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
