@@ -2,34 +2,24 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Activity\Provider;
 
 use OCA\Talk\Config;
+use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Manager;
+use OCA\Talk\Model\Attendee;
 use OCA\Talk\Room;
 use OCA\Talk\Service\AvatarService;
+use OCA\Talk\Service\ParticipantService;
+use OCP\Activity\Exceptions\UnknownActivityException;
 use OCP\Activity\IEvent;
 use OCP\Activity\IManager;
 use OCP\Activity\IProvider;
+use OCP\Federation\ICloudIdManager;
 use OCP\IL10N;
 use OCP\IURLGenerator;
 use OCP\IUser;
@@ -37,46 +27,34 @@ use OCP\IUserManager;
 use OCP\L10N\IFactory;
 
 abstract class Base implements IProvider {
-	protected IFactory $languageFactory;
-	protected IURLGenerator $url;
-	protected Config $config;
-	protected IManager $activityManager;
-	protected AvatarService $avatarService;
-	protected IUserManager $userManager;
-	protected Manager $manager;
 
 	public function __construct(
-		IFactory $languageFactory,
-		IURLGenerator $url,
-		Config $config,
-		IManager $activityManager,
-		IUserManager $userManager,
-		AvatarService $avatarService,
-		Manager $manager,
+		protected IFactory $languageFactory,
+		protected IURLGenerator $url,
+		protected Config $config,
+		protected IManager $activityManager,
+		protected IUserManager $userManager,
+		protected ICloudIdManager $cloudIdManager,
+		protected ParticipantService $participantService,
+		protected AvatarService $avatarService,
+		protected Manager $manager,
 	) {
-		$this->languageFactory = $languageFactory;
-		$this->url = $url;
-		$this->config = $config;
-		$this->activityManager = $activityManager;
-		$this->userManager = $userManager;
-		$this->avatarService = $avatarService;
-		$this->manager = $manager;
 	}
 
 	/**
 	 * @param IEvent $event
 	 * @return IEvent
-	 * @throws \InvalidArgumentException
+	 * @throws UnknownActivityException
 	 */
 	public function preParse(IEvent $event): IEvent {
 		if ($event->getApp() !== 'spreed') {
-			throw new \InvalidArgumentException('Wrong app');
+			throw new UnknownActivityException('app');
 		}
 
 		$uid = $event->getAffectedUser();
 		$user = $this->userManager->get($uid);
 		if (!$user instanceof IUser || $this->config->isDisabledForUser($user)) {
-			throw new \InvalidArgumentException('User can not user Talk');
+			throw new UnknownActivityException('User can not use Talk');
 		}
 
 		if ($this->activityManager->getRequirePNG()) {
@@ -92,7 +70,6 @@ abstract class Base implements IProvider {
 	 * @param IEvent $event
 	 * @param string $subject
 	 * @param array $parameters
-	 * @throws \InvalidArgumentException
 	 */
 	protected function setSubjects(IEvent $event, string $subject, array $parameters): void {
 		$placeholders = $replacements = [];
@@ -122,7 +99,7 @@ abstract class Base implements IProvider {
 
 		return [
 			'type' => 'call',
-			'id' => $room->getId(),
+			'id' => (string)$room->getId(),
 			'name' => $room->getDisplayName($userId),
 			'link' => $this->url->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()]),
 			'call-type' => $stringType,
@@ -130,12 +107,11 @@ abstract class Base implements IProvider {
 		];
 	}
 
-	protected function getFormerRoom(IL10N $l, int $roomId): array {
+	protected function getFormerRoom(IL10N $l): array {
 		return [
-			'type' => 'call',
-			'id' => $roomId,
+			'type' => 'highlight',
+			'id' => 'deleted',
 			'name' => $l->t('a conversation'),
-			'call-type' => Room::TYPE_UNKNOWN,
 		];
 	}
 
@@ -146,4 +122,21 @@ abstract class Base implements IProvider {
 			'name' => $this->userManager->getDisplayName($uid) ?? $uid,
 		];
 	}
+
+	protected function getRemoteUser(Room $room, string $federationId): array {
+		$cloudId = $this->cloudIdManager->resolveCloudId($federationId);
+		$displayName = $cloudId->getDisplayId();
+		try {
+			$participant = $this->participantService->getParticipantByActor($room, Attendee::ACTOR_FEDERATED_USERS, $federationId);
+			$displayName = $participant->getAttendee()->getDisplayName();
+		} catch (ParticipantNotFoundException) {
+		}
+
+		return [
+			'type' => 'user',
+			'id' => $cloudId->getUser(),
+			'name' => $displayName,
+			'server' => $cloudId->getRemote(),
+		];
+	}
 }
