@@ -2,32 +2,23 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Daniel Rudolf <nextcloud.com@daniel-rudolf.de>
- *
- * @author Daniel Rudolf <nextcloud.com@daniel-rudolf.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Command\Room;
 
 use InvalidArgumentException;
+use OCA\Talk\Events\AAttendeeRemovedEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\Exceptions\RoomProperty\DescriptionException;
+use OCA\Talk\Exceptions\RoomProperty\ListableException;
+use OCA\Talk\Exceptions\RoomProperty\MessageExpirationException;
+use OCA\Talk\Exceptions\RoomProperty\NameException;
+use OCA\Talk\Exceptions\RoomProperty\PasswordException;
+use OCA\Talk\Exceptions\RoomProperty\ReadOnlyException;
+use OCA\Talk\Exceptions\RoomProperty\TypeException;
 use OCA\Talk\Manager;
 use OCA\Talk\MatterbridgeManager;
 use OCA\Talk\Model\Attendee;
@@ -35,7 +26,6 @@ use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\RoomService;
-use OCP\HintException;
 use OCP\IGroup;
 use OCP\IGroupManager;
 use OCP\IUser;
@@ -45,39 +35,19 @@ use Symfony\Component\Console\Input\ArgvInput;
 use Symfony\Component\Console\Input\InputDefinition;
 
 trait TRoomCommand {
-	/** @var Manager */
-	protected $manager;
-
-	/** @var RoomService */
-	protected $roomService;
-
-	/** @var ParticipantService */
-	protected $participantService;
-
-	/** @var IUserManager */
-	protected $userManager;
-
-	/** @var IGroupManager */
-	protected $groupManager;
 
 	public function __construct(
-		Manager $manager,
-		RoomService $roomService,
-		ParticipantService $participantService,
-		IUserManager $userManager,
-		IGroupManager $groupManager,
+		protected Manager $manager,
+		protected RoomService $roomService,
+		protected ParticipantService $participantService,
+		protected IUserManager $userManager,
+		protected IGroupManager $groupManager,
 	) {
 		parent::__construct();
-
-		$this->manager = $manager;
-		$this->roomService = $roomService;
-		$this->participantService = $participantService;
-		$this->userManager = $userManager;
-		$this->groupManager = $groupManager;
 	}
 
 	/**
-	 * @param Room   $room
+	 * @param Room $room
 	 * @param string $name
 	 *
 	 * @throws InvalidArgumentException
@@ -92,7 +62,9 @@ trait TRoomCommand {
 			throw new InvalidArgumentException('Invalid room name.');
 		}
 
-		if (!$this->roomService->setName($room, $name)) {
+		try {
+			$this->roomService->setName($room, $name);
+		} catch (NameException) {
 			throw new InvalidArgumentException('Unable to change room name.');
 		}
 	}
@@ -110,7 +82,7 @@ trait TRoomCommand {
 	}
 
 	/**
-	 * @param Room   $room
+	 * @param Room $room
 	 * @param string $description
 	 *
 	 * @throws InvalidArgumentException
@@ -118,7 +90,7 @@ trait TRoomCommand {
 	protected function setRoomDescription(Room $room, string $description): void {
 		try {
 			$this->roomService->setDescription($room, $description);
-		} catch (\LengthException $e) {
+		} catch (DescriptionException $e) {
 			throw new InvalidArgumentException('Invalid room description.');
 		}
 	}
@@ -134,7 +106,9 @@ trait TRoomCommand {
 			return;
 		}
 
-		if (!$this->roomService->setType($room, $public ? Room::TYPE_PUBLIC : Room::TYPE_GROUP)) {
+		try {
+			$this->roomService->setType($room, $public ? Room::TYPE_PUBLIC : Room::TYPE_GROUP);
+		} catch (TypeException) {
 			throw new InvalidArgumentException('Unable to change room type.');
 		}
 	}
@@ -150,7 +124,9 @@ trait TRoomCommand {
 			return;
 		}
 
-		if (!$this->roomService->setReadOnly($room, $readOnly ? Room::READ_ONLY : Room::READ_WRITE)) {
+		try {
+			$this->roomService->setReadOnly($room, $readOnly ? Room::READ_ONLY : Room::READ_WRITE);
+		} catch (ReadOnlyException) {
 			throw new InvalidArgumentException('Unable to change room state.');
 		}
 	}
@@ -166,13 +142,15 @@ trait TRoomCommand {
 			return;
 		}
 
-		if (!$this->roomService->setListable($room, $listable)) {
+		try {
+			$this->roomService->setListable($room, $listable);
+		} catch (ListableException) {
 			throw new InvalidArgumentException('Unable to change room state.');
 		}
 	}
 
 	/**
-	 * @param Room   $room
+	 * @param Room $room
 	 * @param string $password
 	 *
 	 * @throws InvalidArgumentException
@@ -187,16 +165,17 @@ trait TRoomCommand {
 		}
 
 		try {
-			if (!$this->roomService->setPassword($room, $password)) {
-				throw new InvalidArgumentException('Unable to change room password.');
+			$this->roomService->setPassword($room, $password);
+		} catch (PasswordException $e) {
+			if ($e->getReason() === PasswordException::REASON_VALUE) {
+				throw new InvalidArgumentException($e->getHint());
 			}
-		} catch (HintException $e) {
-			throw new InvalidArgumentException($e->getHint());
+			throw new InvalidArgumentException('Unable to change room password.');
 		}
 	}
 
 	/**
-	 * @param Room   $room
+	 * @param Room $room
 	 * @param string $userId
 	 *
 	 * @throws InvalidArgumentException
@@ -232,7 +211,7 @@ trait TRoomCommand {
 	}
 
 	/**
-	 * @param Room     $room
+	 * @param Room $room
 	 * @param string[] $groupIds
 	 *
 	 * @throws InvalidArgumentException
@@ -253,7 +232,7 @@ trait TRoomCommand {
 	}
 
 	/**
-	 * @param Room     $room
+	 * @param Room $room
 	 * @param string[] $userIds
 	 *
 	 * @throws InvalidArgumentException
@@ -263,6 +242,7 @@ trait TRoomCommand {
 			return;
 		}
 
+		/** @var array<string, array{actorType: string, actorId: string, displayName: string}> $participants */
 		$participants = [];
 		foreach ($userIds as $userId) {
 			if ($userId === MatterbridgeManager::BRIDGE_BOT_USERID) {
@@ -288,7 +268,7 @@ trait TRoomCommand {
 				// we expect the user not to be a participant yet
 			}
 
-			$participants[] = [
+			$participants[$user->getUID()] = [
 				'actorType' => Attendee::ACTOR_USERS,
 				'actorId' => $user->getUID(),
 				'displayName' => $user->getDisplayName(),
@@ -299,7 +279,7 @@ trait TRoomCommand {
 	}
 
 	/**
-	 * @param Room     $room
+	 * @param Room $room
 	 * @param string[] $userIds
 	 *
 	 * @throws InvalidArgumentException
@@ -317,12 +297,12 @@ trait TRoomCommand {
 		}
 
 		foreach ($users as $user) {
-			$this->participantService->removeUser($room, $user, Room::PARTICIPANT_REMOVED);
+			$this->participantService->removeUser($room, $user, AAttendeeRemovedEvent::REASON_REMOVED);
 		}
 	}
 
 	/**
-	 * @param Room     $room
+	 * @param Room $room
 	 * @param string[] $userIds
 	 *
 	 * @throws InvalidArgumentException
@@ -351,7 +331,7 @@ trait TRoomCommand {
 	}
 
 	/**
-	 * @param Room     $room
+	 * @param Room $room
 	 * @param string[] $userIds
 	 *
 	 * @throws InvalidArgumentException
@@ -428,6 +408,10 @@ trait TRoomCommand {
 	}
 
 	protected function setMessageExpiration(Room $room, int $seconds): void {
-		$this->roomService->setMessageExpiration($room, $seconds);
+		try {
+			$this->roomService->setMessageExpiration($room, $seconds);
+		} catch (MessageExpirationException) {
+			throw new InvalidArgumentException('Unable to change message expiration.');
+		}
 	}
 }
