@@ -2,34 +2,21 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Listener;
 
 use OCA\Circles\CirclesManager;
 use OCA\Circles\Model\Member;
+use OCA\Talk\Events\AAttendeeRemovedEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
+use OCA\Talk\Service\BanService;
 use OCA\Talk\Service\ParticipantService;
 use OCP\App\IAppManager;
 use OCP\EventDispatcher\Event;
@@ -43,21 +30,15 @@ use Psr\Log\LoggerInterface;
  * @template-implements IEventListener<Event>
  */
 abstract class AMembershipListener implements IEventListener {
-	protected Manager $manager;
-	protected IAppManager $appManager;
-	protected IGroupManager $groupManager;
-	protected ParticipantService $participantService;
 
 	public function __construct(
-		Manager $manager,
-		IAppManager $appManager,
-		IGroupManager $groupManager,
-		ParticipantService $participantService,
+		protected Manager $manager,
+		protected IAppManager $appManager,
+		protected IGroupManager $groupManager,
+		protected ParticipantService $participantService,
+		protected BanService $banService,
+		protected LoggerInterface $logger,
 	) {
-		$this->manager = $manager;
-		$this->appManager = $appManager;
-		$this->groupManager = $groupManager;
-		$this->participantService = $participantService;
 	}
 
 	protected function removeFromRoomsUnlessStillLinked(array $rooms, IUser $user): void {
@@ -69,7 +50,7 @@ abstract class AMembershipListener implements IEventListener {
 				$participant = $room->getParticipant($user->getUID());
 				$participantType = $participant->getAttendee()->getParticipantType();
 				if ($participantType === Participant::USER) {
-					$this->participantService->removeUser($room, $user, Room::PARTICIPANT_REMOVED);
+					$this->participantService->removeUser($room, $user, AAttendeeRemovedEvent::REASON_REMOVED);
 				}
 			} catch (ParticipantNotFoundException $e) {
 			}
