@@ -21,10 +21,11 @@ use OCP\EventDispatcher\IEventListener;
 class CircleEditedListener implements IEventListener {
 
 	public function __construct(
-		readonly private ParticipantService $participantService,
+		private readonly ParticipantService $participantService,
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!$event instanceof EditingCircleEvent && !$event instanceof CircleEditedEvent) {
 			// Unrelated
