@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2021 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Migration;
@@ -31,21 +16,19 @@ use OCP\Migration\IOutput;
 use OCP\Migration\IRepairStep;
 
 class CacheUserDisplayNames implements IRepairStep {
-	protected IDBConnection $connection;
-	protected IUserManager $userManager;
 
 	public function __construct(
-		IDBConnection $connection,
-		IUserManager $userManager,
+		protected IDBConnection $connection,
+		protected IUserManager $userManager,
 	) {
-		$this->connection = $connection;
-		$this->userManager = $userManager;
 	}
 
+	#[\Override]
 	public function getName(): string {
 		return 'Cache the user display names';
 	}
 
+	#[\Override]
 	public function run(IOutput $output): void {
 		$update = $this->connection->getQueryBuilder();
 		$update->update('talk_attendees')
