@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Migration;
@@ -28,16 +13,18 @@ use OCP\Migration\IOutput;
 use OCP\Migration\IRepairStep;
 
 class FixNamespaceInDatabaseTables implements IRepairStep {
-	protected IDBConnection $connection;
 
-	public function __construct(IDBConnection $connection) {
-		$this->connection = $connection;
+	public function __construct(
+		protected IDBConnection $connection,
+	) {
 	}
 
+	#[\Override]
 	public function getName(): string {
 		return 'Fix the namespace in database tables';
 	}
 
+	#[\Override]
 	public function run(IOutput $output): void {
 		$update = $this->connection->getQueryBuilder();
 		$update->update('jobs')
@@ -48,13 +35,13 @@ class FixNamespaceInDatabaseTables implements IRepairStep {
 		$query->select('id', 'class')
 			->from('jobs')
 			->where($query->expr()->like('class', $query->createNamedParameter(
-				'%' . $this->connection->escapeLikeParameter('Spreed'). '%'
+				'%' . $this->connection->escapeLikeParameter('Spreed') . '%'
 			)));
 
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
 			$oldClass = $row['class'];
-			if (strpos($oldClass, 'OCA\\Spreed\\') !== 0) {
+			if (!str_starts_with($oldClass, 'OCA\\Spreed\\')) {
 				continue;
 			}
 
