@@ -3,24 +3,8 @@
 declare(strict_types=1);
 
 /**
- *
- * @copyright Copyright (c) 2018, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\PublicShare;
@@ -37,6 +21,7 @@ use OCP\ICacheFactory;
 use OCP\IConfig;
 use OCP\IGroupManager;
 use OCP\Util;
+use Psr\Log\LoggerInterface;
 
 /**
  * Helper class to extend the "publicshare" template from the server.
@@ -54,18 +39,21 @@ class TemplateLoader implements IEventListener {
 		Config $talkConfig,
 		IConfig $serverConfig,
 		IGroupManager $groupManager,
+		LoggerInterface $logger,
 	) {
 		$this->initialState = $initialState;
 		$this->talkConfig = $talkConfig;
 		$this->memcacheFactory = $memcacheFactory;
 		$this->serverConfig = $serverConfig;
 		$this->groupManager = $groupManager;
+		$this->logger = $logger;
 	}
 
 	/**
 	 * Load the "Talk sidebar" UI in the public share page for the given share.
 	 * @param Event $event
 	 */
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!$event instanceof BeforeTemplateRenderedEvent) {
 			return;
@@ -76,8 +64,8 @@ class TemplateLoader implements IEventListener {
 			return;
 		}
 
-		if ($this->serverConfig->getAppValue('spreed', 'conversations_files', '1') !== '1' ||
-			$this->serverConfig->getAppValue('spreed', 'conversations_files_public_shares', '1') !== '1') {
+		if ($this->serverConfig->getAppValue('spreed', 'conversations_files', '1') !== '1'
+			|| $this->serverConfig->getAppValue('spreed', 'conversations_files_public_shares', '1') !== '1') {
 			return;
 		}
 
@@ -86,9 +74,9 @@ class TemplateLoader implements IEventListener {
 			return;
 		}
 
-		Util::addStyle(Application::APP_ID, 'icons');
-		Util::addStyle(Application::APP_ID, 'publicshare');
+		Util::addStyle(Application::APP_ID, 'talk-icons');
 		Util::addScript(Application::APP_ID, 'talk-public-share-sidebar');
+		Util::addStyle(Application::APP_ID, 'talk-public-share-sidebar');
 
 		$this->publishInitialStateForGuest();
 	}
