@@ -2,25 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2022 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Service;
@@ -28,13 +11,16 @@ namespace OCA\Talk\Service;
 use InvalidArgumentException;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Config;
+use OCA\Talk\Events\AAttendeeRemovedEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
+use OCA\Talk\Exceptions\RoomProperty\BreakoutRoomModeException;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\BreakoutRoom;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Webinary;
+use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IL10N;
 use OCP\Notification\IManager as INotificationManager;
@@ -47,6 +33,7 @@ class BreakoutRoomService {
 		protected ParticipantService $participantService,
 		protected ChatManager $chatManager,
 		protected INotificationManager $notificationManager,
+		protected ITimeFactory $timeFactory,
 		protected IEventDispatcher $dispatcher,
 		protected IL10N $l,
 	) {
@@ -103,8 +90,8 @@ class BreakoutRoomService {
 
 	/**
 	 * @param Room $parent
-	 * @param int $mode
-	 * @psalm-param 0|1|2|3 $mode
+	 * @param 0|1|2|3 $mode
+	 * @psalm-param BreakoutRoom::MODE_* $mode
 	 * @param int $amount
 	 * @param string $attendeeMap
 	 * @return Room[]
@@ -129,7 +116,9 @@ class BreakoutRoomService {
 			throw new InvalidArgumentException('room');
 		}
 
-		if (!$this->roomService->setBreakoutRoomMode($parent, $mode)) {
+		try {
+			$this->roomService->setBreakoutRoomMode($parent, $mode);
+		} catch (BreakoutRoomModeException) {
 			throw new InvalidArgumentException('mode');
 		}
 
@@ -173,7 +162,7 @@ class BreakoutRoomService {
 					continue;
 				}
 
-				$roomNumber = (int) $cleanedMap[$participant->getAttendee()->getId()];
+				$roomNumber = (int)$cleanedMap[$participant->getAttendee()->getId()];
 
 				$map[$roomNumber] ??= [];
 				$map[$roomNumber][] = $participant;
@@ -226,7 +215,7 @@ class BreakoutRoomService {
 				if ($attendee->getActorType() === Attendee::ACTOR_USERS && in_array($attendee->getActorId(), $userIds, true)) {
 					if ($participant->hasModeratorPermissions()) {
 						// Can not remove moderators with this method
-						throw new \InvalidArgumentException('moderator');
+						throw new InvalidArgumentException('moderator');
 					}
 
 					$removals[] = [
@@ -238,7 +227,7 @@ class BreakoutRoomService {
 		}
 
 		foreach ($removals as $removal) {
-			$this->participantService->removeAttendee($removal['room'], $removal['participant'], Room::PARTICIPANT_REMOVED);
+			$this->participantService->removeAttendee($removal['room'], $removal['participant'], AAttendeeRemovedEvent::REASON_REMOVED);
 		}
 
 		$map = [];
@@ -247,7 +236,7 @@ class BreakoutRoomService {
 				continue;
 			}
 
-			$roomNumber = (int) $cleanedMap[$participant->getAttendee()->getId()];
+			$roomNumber = (int)$cleanedMap[$participant->getAttendee()->getId()];
 
 			$map[$roomNumber] ??= [];
 			$map[$roomNumber][] = $participant;
@@ -319,7 +308,7 @@ class BreakoutRoomService {
 		for ($i = 1; $i <= $amount; $i++) {
 			$breakoutRoom = $this->roomService->createConversation(
 				$parent->getType(),
-				str_replace('{number}', (string) $i, $label),
+				str_replace('{number}', (string)$i, $label),
 				null,
 				BreakoutRoom::PARENT_OBJECT_TYPE,
 				$parent->getToken()
@@ -336,6 +325,7 @@ class BreakoutRoomService {
 	public function removeBreakoutRooms(Room $parent): void {
 		$this->deleteBreakoutRooms($parent);
 		$this->roomService->setBreakoutRoomMode($parent, BreakoutRoom::MODE_NOT_CONFIGURED);
+		$this->roomService->setBreakoutRoomStatus($parent, BreakoutRoom::STATUS_STOPPED);
 	}
 
 	protected function deleteBreakoutRooms(Room $parent): void {
@@ -353,7 +343,7 @@ class BreakoutRoomService {
 	 */
 	public function broadcastChatMessage(Room $parent, Participant $participant, string $message): array {
 		if ($parent->getBreakoutRoomMode() === BreakoutRoom::MODE_NOT_CONFIGURED) {
-			throw new \InvalidArgumentException('mode');
+			throw new InvalidArgumentException('mode');
 		}
 
 		$breakoutRooms = $this->manager->getMultipleRoomsByObject(BreakoutRoom::PARENT_OBJECT_TYPE, $parent->getToken());
@@ -365,7 +355,7 @@ class BreakoutRoomService {
 		try {
 			foreach ($breakoutRooms as $breakoutRoom) {
 				$breakoutParticipant = $this->participantService->getParticipantByActor($breakoutRoom, $attendeeType, $attendeeId);
-				$comment = $this->chatManager->sendMessage($breakoutRoom, $breakoutParticipant, $attendeeType, $attendeeId, $message, $creationDateTime, null, '', false);
+				$comment = $this->chatManager->sendMessage($breakoutRoom, $breakoutParticipant, $attendeeType, $attendeeId, $message, $creationDateTime, rateLimitGuestMentions: false);
 				$breakoutRoom->setLastMessage($comment);
 			}
 		} finally {
@@ -387,21 +377,22 @@ class BreakoutRoomService {
 
 	protected function setAssistanceRequest(Room $breakoutRoom, int $status): void {
 		if ($breakoutRoom->getObjectType() !== BreakoutRoom::PARENT_OBJECT_TYPE) {
-			throw new \InvalidArgumentException('room');
+			throw new InvalidArgumentException('room');
 		}
 
 		if ($breakoutRoom->getLobbyState() !== Webinary::LOBBY_NONE) {
-			throw new \InvalidArgumentException('room');
+			throw new InvalidArgumentException('room');
 		}
 
 		if (!in_array($status, [
 			BreakoutRoom::STATUS_ASSISTANCE_RESET,
 			BreakoutRoom::STATUS_ASSISTANCE_REQUESTED,
 		], true)) {
-			throw new \InvalidArgumentException('status');
+			throw new InvalidArgumentException('status');
 		}
 
 		$this->roomService->setBreakoutRoomStatus($breakoutRoom, $status);
+		$this->roomService->setLastActivity($breakoutRoom, $this->timeFactory->getDateTime());
 	}
 
 	/**
@@ -410,10 +401,10 @@ class BreakoutRoomService {
 	 */
 	public function startBreakoutRooms(Room $parent): array {
 		if ($parent->getBreakoutRoomMode() === BreakoutRoom::MODE_NOT_CONFIGURED) {
-			throw new \InvalidArgumentException('mode');
+			throw new InvalidArgumentException('mode');
 		}
 
-		$breakoutRooms = $this->manager->getMultipleRoomsByObject(BreakoutRoom::PARENT_OBJECT_TYPE, $parent->getToken());
+		$breakoutRooms = $this->manager->getMultipleRoomsByObject(BreakoutRoom::PARENT_OBJECT_TYPE, $parent->getToken(), true);
 		foreach ($breakoutRooms as $breakoutRoom) {
 			$this->roomService->setLobby($breakoutRoom, Webinary::LOBBY_NONE, null);
 		}
@@ -429,12 +420,12 @@ class BreakoutRoomService {
 	 */
 	public function stopBreakoutRooms(Room $parent): array {
 		if ($parent->getBreakoutRoomMode() === BreakoutRoom::MODE_NOT_CONFIGURED) {
-			throw new \InvalidArgumentException('mode');
+			throw new InvalidArgumentException('mode');
 		}
 
 		$this->roomService->setBreakoutRoomStatus($parent, BreakoutRoom::STATUS_STOPPED);
 
-		$breakoutRooms = $this->manager->getMultipleRoomsByObject(BreakoutRoom::PARENT_OBJECT_TYPE, $parent->getToken());
+		$breakoutRooms = $this->manager->getMultipleRoomsByObject(BreakoutRoom::PARENT_OBJECT_TYPE, $parent->getToken(), true);
 		foreach ($breakoutRooms as $breakoutRoom) {
 			$this->roomService->setLobby($breakoutRoom, Webinary::LOBBY_NON_MODERATORS, null);
 
@@ -448,16 +439,16 @@ class BreakoutRoomService {
 
 	public function switchBreakoutRoom(Room $parent, Participant $participant, string $targetToken): Room {
 		if ($parent->getBreakoutRoomMode() !== BreakoutRoom::MODE_FREE) {
-			throw new \InvalidArgumentException('mode');
+			throw new InvalidArgumentException('mode');
 		}
 
 		if ($parent->getBreakoutRoomStatus() !== BreakoutRoom::STATUS_STARTED) {
-			throw new \InvalidArgumentException('status');
+			throw new InvalidArgumentException('status');
 		}
 
 		if ($participant->hasModeratorPermissions()) {
 			// Moderators don't switch, they are part of all breakout rooms
-			throw new \InvalidArgumentException('moderator');
+			throw new InvalidArgumentException('moderator');
 		}
 
 		$attendee = $participant->getAttendee();
@@ -473,7 +464,7 @@ class BreakoutRoomService {
 		}
 
 		if ($target === null) {
-			throw new \InvalidArgumentException('target');
+			throw new InvalidArgumentException('target');
 		}
 
 		foreach ($breakoutRooms as $breakoutRoom) {
@@ -489,7 +480,7 @@ class BreakoutRoomService {
 					$this->participantService->removeAttendee(
 						$breakoutRoom,
 						$removeParticipant,
-						Room::PARTICIPANT_LEFT
+						AAttendeeRemovedEvent::REASON_LEFT
 					);
 				}
 			} catch (ParticipantNotFoundException $e) {
@@ -520,11 +511,11 @@ class BreakoutRoomService {
 	 */
 	public function getBreakoutRooms(Room $parent, Participant $participant): array {
 		if ($parent->getBreakoutRoomMode() === BreakoutRoom::MODE_NOT_CONFIGURED) {
-			throw new \InvalidArgumentException('mode');
+			throw new InvalidArgumentException('mode');
 		}
 
 		if (!$participant->hasModeratorPermissions() && $parent->getBreakoutRoomStatus() !== BreakoutRoom::STATUS_STARTED) {
-			throw new \InvalidArgumentException('status');
+			throw new InvalidArgumentException('status');
 		}
 
 		$breakoutRooms = $this->manager->getMultipleRoomsByObject(BreakoutRoom::PARENT_OBJECT_TYPE, $parent->getToken(), true);
@@ -569,10 +560,10 @@ class BreakoutRoomService {
 				);
 
 				if ($throwOnModerator && $participant->hasModeratorPermissions()) {
-					throw new \InvalidArgumentException('moderator');
+					throw new InvalidArgumentException('moderator');
 				}
 
-				$this->participantService->removeAttendee($breakoutRoom, $participant, Room::PARTICIPANT_REMOVED);
+				$this->participantService->removeAttendee($breakoutRoom, $participant, AAttendeeRemovedEvent::REASON_REMOVED);
 			} catch (ParticipantNotFoundException $e) {
 				// Skip this room
 			}
